# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/listing/params.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/listing/params.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!dydxprotocol/listing/params.proto\x12\x14\x64ydxprotocol.listing\x1a\x14gogoproto/gogo.proto\"\x97\x02\n\x19ListingVaultDepositParams\x12j\n\x18new_vault_deposit_amount\x18\x01 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\x12k\n\x19main_vault_deposit_amount\x18\x02 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\x12!\n\x19num_blocks_to_lock_shares\x18\x03 \x01(\rB;Z9github.com/dydxprotocol/v4-chain/protocol/x/listing/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.listing.params_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z9github.com/dydxprotocol/v4-chain/protocol/x/listing/types'
  _globals['_LISTINGVAULTDEPOSITPARAMS'].fields_by_name['new_vault_deposit_amount']._loaded_options = None
  _globals['_LISTINGVAULTDEPOSITPARAMS'].fields_by_name['new_vault_deposit_amount']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_LISTINGVAULTDEPOSITPARAMS'].fields_by_name['main_vault_deposit_amount']._loaded_options = None
  _globals['_LISTINGVAULTDEPOSITPARAMS'].fields_by_name['main_vault_deposit_amount']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_LISTINGVAULTDEPOSITPARAMS']._serialized_start=82
  _globals['_LISTINGVAULTDEPOSITPARAMS']._serialized_end=361
# @@protoc_insertion_point(module_scope)



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from v4_proto.cosmos.bank.v1beta1 import bank_pb2 as _bank_pb2
from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as _msg_pb2
from v4_proto.amino import amino_pb2 as _amino_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MsgSend(_message.Message):
    __slots__ = ("from_address", "to_address", "amount")
    FROM_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    TO_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    from_address: str
    to_address: str
    amount: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    def __init__(self, from_address: _Optional[str] = ..., to_address: _Optional[str] = ..., amount: _Optional[_Iterable[_Union[_coin_pb2.Coin, _Mapping]]] = ...) -> None: ...

class MsgSendResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgMultiSend(_message.Message):
    __slots__ = ("inputs", "outputs")
    INPUTS_FIELD_NUMBER: _ClassVar[int]
    OUTPUTS_FIELD_NUMBER: _ClassVar[int]
    inputs: _containers.RepeatedCompositeFieldContainer[_bank_pb2.Input]
    outputs: _containers.RepeatedCompositeFieldContainer[_bank_pb2.Output]
    def __init__(self, inputs: _Optional[_Iterable[_Union[_bank_pb2.Input, _Mapping]]] = ..., outputs: _Optional[_Iterable[_Union[_bank_pb2.Output, _Mapping]]] = ...) -> None: ...

class MsgMultiSendResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgUpdateParams(_message.Message):
    __slots__ = ("authority", "params")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    authority: str
    params: _bank_pb2.Params
    def __init__(self, authority: _Optional[str] = ..., params: _Optional[_Union[_bank_pb2.Params, _Mapping]] = ...) -> None: ...

class MsgUpdateParamsResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgSetSendEnabled(_message.Message):
    __slots__ = ("authority", "send_enabled", "use_default_for")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    SEND_ENABLED_FIELD_NUMBER: _ClassVar[int]
    USE_DEFAULT_FOR_FIELD_NUMBER: _ClassVar[int]
    authority: str
    send_enabled: _containers.RepeatedCompositeFieldContainer[_bank_pb2.SendEnabled]
    use_default_for: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, authority: _Optional[str] = ..., send_enabled: _Optional[_Iterable[_Union[_bank_pb2.SendEnabled, _Mapping]]] = ..., use_default_for: _Optional[_Iterable[str]] = ...) -> None: ...

class MsgSetSendEnabledResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as _msg_pb2
from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.dydxprotocol.subaccounts import subaccount_pb2 as _subaccount_pb2
from v4_proto.dydxprotocol.listing import params_pb2 as _params_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MsgSetMarketsHardCap(_message.Message):
    __slots__ = ("authority", "hard_cap_for_markets")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    HARD_CAP_FOR_MARKETS_FIELD_NUMBER: _ClassVar[int]
    authority: str
    hard_cap_for_markets: int
    def __init__(self, authority: _Optional[str] = ..., hard_cap_for_markets: _Optional[int] = ...) -> None: ...

class MsgSetMarketsHardCapResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgCreateMarketPermissionless(_message.Message):
    __slots__ = ("ticker", "subaccount_id")
    TICKER_FIELD_NUMBER: _ClassVar[int]
    SUBACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    ticker: str
    subaccount_id: _subaccount_pb2.SubaccountId
    def __init__(self, ticker: _Optional[str] = ..., subaccount_id: _Optional[_Union[_subaccount_pb2.SubaccountId, _Mapping]] = ...) -> None: ...

class MsgCreateMarketPermissionlessResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgSetListingVaultDepositParams(_message.Message):
    __slots__ = ("authority", "params")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    authority: str
    params: _params_pb2.ListingVaultDepositParams
    def __init__(self, authority: _Optional[str] = ..., params: _Optional[_Union[_params_pb2.ListingVaultDepositParams, _Mapping]] = ...) -> None: ...

class MsgSetListingVaultDepositParamsResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgUpgradeIsolatedPerpetualToCross(_message.Message):
    __slots__ = ("authority", "perpetual_id")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    PERPETUAL_ID_FIELD_NUMBER: _ClassVar[int]
    authority: str
    perpetual_id: int
    def __init__(self, authority: _Optional[str] = ..., perpetual_id: _Optional[int] = ...) -> None: ...

class MsgUpgradeIsolatedPerpetualToCrossResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class LiquidationsConfig(_message.Message):
    __slots__ = ("max_liquidation_fee_ppm", "position_block_limits", "subaccount_block_limits", "fillable_price_config")
    MAX_LIQUIDATION_FEE_PPM_FIELD_NUMBER: _ClassVar[int]
    POSITION_BLOCK_LIMITS_FIELD_NUMBER: _ClassVar[int]
    SUBACCOUNT_BLOCK_LIMITS_FIELD_NUMBER: _ClassVar[int]
    FILLABLE_PRICE_CONFIG_FIELD_NUMBER: _ClassVar[int]
    max_liquidation_fee_ppm: int
    position_block_limits: PositionBlockLimits
    subaccount_block_limits: SubaccountBlockLimits
    fillable_price_config: FillablePriceConfig
    def __init__(self, max_liquidation_fee_ppm: _Optional[int] = ..., position_block_limits: _Optional[_Union[PositionBlockLimits, _Mapping]] = ..., subaccount_block_limits: _Optional[_Union[SubaccountBlockLimits, _Mapping]] = ..., fillable_price_config: _Optional[_Union[FillablePriceConfig, _Mapping]] = ...) -> None: ...

class PositionBlockLimits(_message.Message):
    __slots__ = ("min_position_notional_liquidated", "max_position_portion_liquidated_ppm")
    MIN_POSITION_NOTIONAL_LIQUIDATED_FIELD_NUMBER: _ClassVar[int]
    MAX_POSITION_PORTION_LIQUIDATED_PPM_FIELD_NUMBER: _ClassVar[int]
    min_position_notional_liquidated: int
    max_position_portion_liquidated_ppm: int
    def __init__(self, min_position_notional_liquidated: _Optional[int] = ..., max_position_portion_liquidated_ppm: _Optional[int] = ...) -> None: ...

class SubaccountBlockLimits(_message.Message):
    __slots__ = ("max_notional_liquidated", "max_quantums_insurance_lost")
    MAX_NOTIONAL_LIQUIDATED_FIELD_NUMBER: _ClassVar[int]
    MAX_QUANTUMS_INSURANCE_LOST_FIELD_NUMBER: _ClassVar[int]
    max_notional_liquidated: int
    max_quantums_insurance_lost: int
    def __init__(self, max_notional_liquidated: _Optional[int] = ..., max_quantums_insurance_lost: _Optional[int] = ...) -> None: ...

class FillablePriceConfig(_message.Message):
    __slots__ = ("bankruptcy_adjustment_ppm", "spread_to_maintenance_margin_ratio_ppm")
    BANKRUPTCY_ADJUSTMENT_PPM_FIELD_NUMBER: _ClassVar[int]
    SPREAD_TO_MAINTENANCE_MARGIN_RATIO_PPM_FIELD_NUMBER: _ClassVar[int]
    bankruptcy_adjustment_ppm: int
    spread_to_maintenance_margin_ratio_ppm: int
    def __init__(self, bankruptcy_adjustment_ppm: _Optional[int] = ..., spread_to_maintenance_margin_ratio_ppm: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/revshare/query.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/revshare/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.dydxprotocol.revshare import params_pb2 as dydxprotocol_dot_revshare_dot_params__pb2
from v4_proto.dydxprotocol.revshare import revshare_pb2 as dydxprotocol_dot_revshare_dot_revshare__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!dydxprotocol/revshare/query.proto\x12\x15\x64ydxprotocol.revshare\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\"dydxprotocol/revshare/params.proto\x1a$dydxprotocol/revshare/revshare.proto\"%\n#QueryMarketMapperRevenueShareParams\"z\n+QueryMarketMapperRevenueShareParamsResponse\x12K\n\x06params\x18\x01 \x01(\x0b\x32\x35.dydxprotocol.revshare.MarketMapperRevenueShareParamsB\x04\xc8\xde\x1f\x00\"5\n QueryMarketMapperRevShareDetails\x12\x11\n\tmarket_id\x18\x01 \x01(\r\"u\n(QueryMarketMapperRevShareDetailsResponse\x12I\n\x07\x64\x65tails\x18\x01 \x01(\x0b\x32\x32.dydxprotocol.revshare.MarketMapperRevShareDetailsB\x04\xc8\xde\x1f\x00\"\"\n QueryUnconditionalRevShareConfig\"t\n(QueryUnconditionalRevShareConfigResponse\x12H\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x32.dydxprotocol.revshare.UnconditionalRevShareConfigB\x04\xc8\xde\x1f\x00\"E\n\x18QueryOrderRouterRevShare\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\"t\n QueryOrderRouterRevShareResponse\x12P\n\x16order_router_rev_share\x18\x01 \x01(\x0b\x32*.dydxprotocol.revshare.OrderRouterRevShareB\x04\xc8\xde\x1f\x00\x32\xe4\x06\n\x05Query\x12\xdf\x01\n\x1eMarketMapperRevenueShareParams\x12:.dydxprotocol.revshare.QueryMarketMapperRevenueShareParams\x1a\x42.dydxprotocol.revshare.QueryMarketMapperRevenueShareParamsResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/dydxprotocol/revshare/market_mapper_rev_share_params\x12\xe3\x01\n\x1bMarketMapperRevShareDetails\x12\x37.dydxprotocol.revshare.QueryMarketMapperRevShareDetails\x1a?.dydxprotocol.revshare.QueryMarketMapperRevShareDetailsResponse\"J\x82\xd3\xe4\x93\x02\x44\x12\x42/dydxprotocol/revshare/market_mapper_rev_share_details/{market_id}\x12\xcf\x01\n\x1bUnconditionalRevShareConfig\x12\x37.dydxprotocol.revshare.QueryUnconditionalRevShareConfig\x1a?.dydxprotocol.revshare.QueryUnconditionalRevShareConfigResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./dydxprotocol/revshare/unconditional_rev_share\x12\xc0\x01\n\x13OrderRouterRevShare\x12/.dydxprotocol.revshare.QueryOrderRouterRevShare\x1a\x37.dydxprotocol.revshare.QueryOrderRouterRevShareResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/dydxprotocol/revshare/order_router_rev_share/{address}B<Z:github.com/dydxprotocol/v4-chain/protocol/x/revshare/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.revshare.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z:github.com/dydxprotocol/v4-chain/protocol/x/revshare/types'
  _globals['_QUERYMARKETMAPPERREVENUESHAREPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYMARKETMAPPERREVENUESHAREPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYMARKETMAPPERREVSHAREDETAILSRESPONSE'].fields_by_name['details']._loaded_options = None
  _globals['_QUERYMARKETMAPPERREVSHAREDETAILSRESPONSE'].fields_by_name['details']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYUNCONDITIONALREVSHARECONFIGRESPONSE'].fields_by_name['config']._loaded_options = None
  _globals['_QUERYUNCONDITIONALREVSHARECONFIGRESPONSE'].fields_by_name['config']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYORDERROUTERREVSHARE'].fields_by_name['address']._loaded_options = None
  _globals['_QUERYORDERROUTERREVSHARE'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYORDERROUTERREVSHARERESPONSE'].fields_by_name['order_router_rev_share']._loaded_options = None
  _globals['_QUERYORDERROUTERREVSHARERESPONSE'].fields_by_name['order_router_rev_share']._serialized_options = b'\310\336\037\000'
  _globals['_QUERY'].methods_by_name['MarketMapperRevenueShareParams']._loaded_options = None
  _globals['_QUERY'].methods_by_name['MarketMapperRevenueShareParams']._serialized_options = b'\202\323\344\223\0027\0225/dydxprotocol/revshare/market_mapper_rev_share_params'
  _globals['_QUERY'].methods_by_name['MarketMapperRevShareDetails']._loaded_options = None
  _globals['_QUERY'].methods_by_name['MarketMapperRevShareDetails']._serialized_options = b'\202\323\344\223\002D\022B/dydxprotocol/revshare/market_mapper_rev_share_details/{market_id}'
  _globals['_QUERY'].methods_by_name['UnconditionalRevShareConfig']._loaded_options = None
  _globals['_QUERY'].methods_by_name['UnconditionalRevShareConfig']._serialized_options = b'\202\323\344\223\0020\022./dydxprotocol/revshare/unconditional_rev_share'
  _globals['_QUERY'].methods_by_name['OrderRouterRevShare']._loaded_options = None
  _globals['_QUERY'].methods_by_name['OrderRouterRevShare']._serialized_options = b'\202\323\344\223\0029\0227/dydxprotocol/revshare/order_router_rev_share/{address}'
  _globals['_QUERYMARKETMAPPERREVENUESHAREPARAMS']._serialized_start=213
  _globals['_QUERYMARKETMAPPERREVENUESHAREPARAMS']._serialized_end=250
  _globals['_QUERYMARKETMAPPERREVENUESHAREPARAMSRESPONSE']._serialized_start=252
  _globals['_QUERYMARKETMAPPERREVENUESHAREPARAMSRESPONSE']._serialized_end=374
  _globals['_QUERYMARKETMAPPERREVSHAREDETAILS']._serialized_start=376
  _globals['_QUERYMARKETMAPPERREVSHAREDETAILS']._serialized_end=429
  _globals['_QUERYMARKETMAPPERREVSHAREDETAILSRESPONSE']._serialized_start=431
  _globals['_QUERYMARKETMAPPERREVSHAREDETAILSRESPONSE']._serialized_end=548
  _globals['_QUERYUNCONDITIONALREVSHARECONFIG']._serialized_start=550
  _globals['_QUERYUNCONDITIONALREVSHARECONFIG']._serialized_end=584
  _globals['_QUERYUNCONDITIONALREVSHARECONFIGRESPONSE']._serialized_start=586
  _globals['_QUERYUNCONDITIONALREVSHARECONFIGRESPONSE']._serialized_end=702
  _globals['_QUERYORDERROUTERREVSHARE']._serialized_start=704
  _globals['_QUERYORDERROUTERREVSHARE']._serialized_end=773
  _globals['_QUERYORDERROUTERREVSHARERESPONSE']._serialized_start=775
  _globals['_QUERYORDERROUTERREVSHARERESPONSE']._serialized_end=891
  _globals['_QUERY']._serialized_start=894
  _globals['_QUERY']._serialized_end=1762
# @@protoc_insertion_point(module_scope)



import datetime

from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import any_pb2 as _any_pb2
from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from v4_proto.amino import amino_pb2 as _amino_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class BasicAllowance(_message.Message):
    __slots__ = ("spend_limit", "expiration")
    SPEND_LIMIT_FIELD_NUMBER: _ClassVar[int]
    EXPIRATION_FIELD_NUMBER: _ClassVar[int]
    spend_limit: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    expiration: _timestamp_pb2.Timestamp
    def __init__(self, spend_limit: _Optional[_Iterable[_Union[_coin_pb2.Coin, _Mapping]]] = ..., expiration: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class PeriodicAllowance(_message.Message):
    __slots__ = ("basic", "period", "period_spend_limit", "period_can_spend", "period_reset")
    BASIC_FIELD_NUMBER: _ClassVar[int]
    PERIOD_FIELD_NUMBER: _ClassVar[int]
    PERIOD_SPEND_LIMIT_FIELD_NUMBER: _ClassVar[int]
    PERIOD_CAN_SPEND_FIELD_NUMBER: _ClassVar[int]
    PERIOD_RESET_FIELD_NUMBER: _ClassVar[int]
    basic: BasicAllowance
    period: _duration_pb2.Duration
    period_spend_limit: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    period_can_spend: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    period_reset: _timestamp_pb2.Timestamp
    def __init__(self, basic: _Optional[_Union[BasicAllowance, _Mapping]] = ..., period: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ..., period_spend_limit: _Optional[_Iterable[_Union[_coin_pb2.Coin, _Mapping]]] = ..., period_can_spend: _Optional[_Iterable[_Union[_coin_pb2.Coin, _Mapping]]] = ..., period_reset: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class AllowedMsgAllowance(_message.Message):
    __slots__ = ("allowance", "allowed_messages")
    ALLOWANCE_FIELD_NUMBER: _ClassVar[int]
    ALLOWED_MESSAGES_FIELD_NUMBER: _ClassVar[int]
    allowance: _any_pb2.Any
    allowed_messages: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, allowance: _Optional[_Union[_any_pb2.Any, _Mapping]] = ..., allowed_messages: _Optional[_Iterable[str]] = ...) -> None: ...

class Grant(_message.Message):
    __slots__ = ("granter", "grantee", "allowance")
    GRANTER_FIELD_NUMBER: _ClassVar[int]
    GRANTEE_FIELD_NUMBER: _ClassVar[int]
    ALLOWANCE_FIELD_NUMBER: _ClassVar[int]
    granter: str
    grantee: str
    allowance: _any_pb2.Any
    def __init__(self, granter: _Optional[str] = ..., grantee: _Optional[str] = ..., allowance: _Optional[_Union[_any_pb2.Any, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/accountplus/query.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/accountplus/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.dydxprotocol.accountplus import accountplus_pb2 as dydxprotocol_dot_accountplus_dot_accountplus__pb2
from v4_proto.dydxprotocol.accountplus import models_pb2 as dydxprotocol_dot_accountplus_dot_models__pb2
from v4_proto.dydxprotocol.accountplus import params_pb2 as dydxprotocol_dot_accountplus_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$dydxprotocol/accountplus/query.proto\x12\x18\x64ydxprotocol.accountplus\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a*dydxprotocol/accountplus/accountplus.proto\x1a%dydxprotocol/accountplus/models.proto\x1a%dydxprotocol/accountplus/params.proto\"&\n\x13\x41\x63\x63ountStateRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"U\n\x14\x41\x63\x63ountStateResponse\x12=\n\raccount_state\x18\x01 \x01(\x0b\x32&.dydxprotocol.accountplus.AccountState\"\x14\n\x12QueryParamsRequest\"M\n\x13QueryParamsResponse\x12\x36\n\x06params\x18\x01 \x01(\x0b\x32 .dydxprotocol.accountplus.ParamsB\x04\xc8\xde\x1f\x00\"+\n\x18GetAuthenticatorsRequest\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\"k\n\x19GetAuthenticatorsResponse\x12N\n\x16\x61\x63\x63ount_authenticators\x18\x01 \x03(\x0b\x32..dydxprotocol.accountplus.AccountAuthenticator\"D\n\x17GetAuthenticatorRequest\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\x12\x18\n\x10\x61uthenticator_id\x18\x02 \x01(\x04\"i\n\x18GetAuthenticatorResponse\x12M\n\x15\x61\x63\x63ount_authenticator\x18\x01 \x01(\x0b\x32..dydxprotocol.accountplus.AccountAuthenticator2\xc9\x05\n\x05Query\x12\x8f\x01\n\x06Params\x12,.dydxprotocol.accountplus.QueryParamsRequest\x1a-.dydxprotocol.accountplus.QueryParamsResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /dydxprotocol/accountplus/params\x12\xc7\x01\n\x10GetAuthenticator\x12\x31.dydxprotocol.accountplus.GetAuthenticatorRequest\x1a\x32.dydxprotocol.accountplus.GetAuthenticatorResponse\"L\x82\xd3\xe4\x93\x02\x46\x12\x44/dydxprotocol/accountplus/authenticator/{account}/{authenticator_id}\x12\xb8\x01\n\x11GetAuthenticators\x12\x32.dydxprotocol.accountplus.GetAuthenticatorsRequest\x1a\x33.dydxprotocol.accountplus.GetAuthenticatorsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/dydxprotocol/accountplus/authenticators/{account}\x12\xa8\x01\n\x0c\x41\x63\x63ountState\x12-.dydxprotocol.accountplus.AccountStateRequest\x1a..dydxprotocol.accountplus.AccountStateResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/dydxprotocol/accountplus/account_state/{address}B?Z=github.com/dydxprotocol/v4-chain/protocol/x/accountplus/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.accountplus.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z=github.com/dydxprotocol/v4-chain/protocol/x/accountplus/types'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\"\022 /dydxprotocol/accountplus/params'
  _globals['_QUERY'].methods_by_name['GetAuthenticator']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetAuthenticator']._serialized_options = b'\202\323\344\223\002F\022D/dydxprotocol/accountplus/authenticator/{account}/{authenticator_id}'
  _globals['_QUERY'].methods_by_name['GetAuthenticators']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetAuthenticators']._serialized_options = b'\202\323\344\223\0024\0222/dydxprotocol/accountplus/authenticators/{account}'
  _globals['_QUERY'].methods_by_name['AccountState']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AccountState']._serialized_options = b'\202\323\344\223\0023\0221/dydxprotocol/accountplus/account_state/{address}'
  _globals['_ACCOUNTSTATEREQUEST']._serialized_start=240
  _globals['_ACCOUNTSTATEREQUEST']._serialized_end=278
  _globals['_ACCOUNTSTATERESPONSE']._serialized_start=280
  _globals['_ACCOUNTSTATERESPONSE']._serialized_end=365
  _globals['_QUERYPARAMSREQUEST']._serialized_start=367
  _globals['_QUERYPARAMSREQUEST']._serialized_end=387
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=389
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=466
  _globals['_GETAUTHENTICATORSREQUEST']._serialized_start=468
  _globals['_GETAUTHENTICATORSREQUEST']._serialized_end=511
  _globals['_GETAUTHENTICATORSRESPONSE']._serialized_start=513
  _globals['_GETAUTHENTICATORSRESPONSE']._serialized_end=620
  _globals['_GETAUTHENTICATORREQUEST']._serialized_start=622
  _globals['_GETAUTHENTICATORREQUEST']._serialized_end=690
  _globals['_GETAUTHENTICATORRESPONSE']._serialized_start=692
  _globals['_GETAUTHENTICATORRESPONSE']._serialized_end=797
  _globals['_QUERY']._serialized_start=800
  _globals['_QUERY']._serialized_end=1513
# @@protoc_insertion_point(module_scope)



from v4_proto.dydxprotocol.subaccounts import subaccount_pb2 as _subaccount_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class StreamSubaccountUpdate(_message.Message):
    __slots__ = ("subaccount_id", "updated_perpetual_positions", "updated_asset_positions", "snapshot")
    SUBACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    UPDATED_PERPETUAL_POSITIONS_FIELD_NUMBER: _ClassVar[int]
    UPDATED_ASSET_POSITIONS_FIELD_NUMBER: _ClassVar[int]
    SNAPSHOT_FIELD_NUMBER: _ClassVar[int]
    subaccount_id: _subaccount_pb2.SubaccountId
    updated_perpetual_positions: _containers.RepeatedCompositeFieldContainer[SubaccountPerpetualPosition]
    updated_asset_positions: _containers.RepeatedCompositeFieldContainer[SubaccountAssetPosition]
    snapshot: bool
    def __init__(self, subaccount_id: _Optional[_Union[_subaccount_pb2.SubaccountId, _Mapping]] = ..., updated_perpetual_positions: _Optional[_Iterable[_Union[SubaccountPerpetualPosition, _Mapping]]] = ..., updated_asset_positions: _Optional[_Iterable[_Union[SubaccountAssetPosition, _Mapping]]] = ..., snapshot: bool = ...) -> None: ...

class SubaccountPerpetualPosition(_message.Message):
    __slots__ = ("perpetual_id", "quantums")
    PERPETUAL_ID_FIELD_NUMBER: _ClassVar[int]
    QUANTUMS_FIELD_NUMBER: _ClassVar[int]
    perpetual_id: int
    quantums: int
    def __init__(self, perpetual_id: _Optional[int] = ..., quantums: _Optional[int] = ...) -> None: ...

class SubaccountAssetPosition(_message.Message):
    __slots__ = ("asset_id", "quantums")
    ASSET_ID_FIELD_NUMBER: _ClassVar[int]
    QUANTUMS_FIELD_NUMBER: _ClassVar[int]
    asset_id: int
    quantums: int
    def __init__(self, asset_id: _Optional[int] = ..., quantums: _Optional[int] = ...) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.dydxprotocol.subaccounts import subaccount_pb2 as _subaccount_pb2
from v4_proto.dydxprotocol.clob import order_pb2 as _order_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ClobMatch(_message.Message):
    __slots__ = ("match_orders", "match_perpetual_liquidation", "match_perpetual_deleveraging")
    MATCH_ORDERS_FIELD_NUMBER: _ClassVar[int]
    MATCH_PERPETUAL_LIQUIDATION_FIELD_NUMBER: _ClassVar[int]
    MATCH_PERPETUAL_DELEVERAGING_FIELD_NUMBER: _ClassVar[int]
    match_orders: MatchOrders
    match_perpetual_liquidation: MatchPerpetualLiquidation
    match_perpetual_deleveraging: MatchPerpetualDeleveraging
    def __init__(self, match_orders: _Optional[_Union[MatchOrders, _Mapping]] = ..., match_perpetual_liquidation: _Optional[_Union[MatchPerpetualLiquidation, _Mapping]] = ..., match_perpetual_deleveraging: _Optional[_Union[MatchPerpetualDeleveraging, _Mapping]] = ...) -> None: ...

class MakerFill(_message.Message):
    __slots__ = ("fill_amount", "maker_order_id")
    FILL_AMOUNT_FIELD_NUMBER: _ClassVar[int]
    MAKER_ORDER_ID_FIELD_NUMBER: _ClassVar[int]
    fill_amount: int
    maker_order_id: _order_pb2.OrderId
    def __init__(self, fill_amount: _Optional[int] = ..., maker_order_id: _Optional[_Union[_order_pb2.OrderId, _Mapping]] = ...) -> None: ...

class MatchOrders(_message.Message):
    __slots__ = ("taker_order_id", "fills")
    TAKER_ORDER_ID_FIELD_NUMBER: _ClassVar[int]
    FILLS_FIELD_NUMBER: _ClassVar[int]
    taker_order_id: _order_pb2.OrderId
    fills: _containers.RepeatedCompositeFieldContainer[MakerFill]
    def __init__(self, taker_order_id: _Optional[_Union[_order_pb2.OrderId, _Mapping]] = ..., fills: _Optional[_Iterable[_Union[MakerFill, _Mapping]]] = ...) -> None: ...

class MatchPerpetualLiquidation(_message.Message):
    __slots__ = ("liquidated", "clob_pair_id", "perpetual_id", "total_size", "is_buy", "fills")
    LIQUIDATED_FIELD_NUMBER: _ClassVar[int]
    CLOB_PAIR_ID_FIELD_NUMBER: _ClassVar[int]
    PERPETUAL_ID_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SIZE_FIELD_NUMBER: _ClassVar[int]
    IS_BUY_FIELD_NUMBER: _ClassVar[int]
    FILLS_FIELD_NUMBER: _ClassVar[int]
    liquidated: _subaccount_pb2.SubaccountId
    clob_pair_id: int
    perpetual_id: int
    total_size: int
    is_buy: bool
    fills: _containers.RepeatedCompositeFieldContainer[MakerFill]
    def __init__(self, liquidated: _Optional[_Union[_subaccount_pb2.SubaccountId, _Mapping]] = ..., clob_pair_id: _Optional[int] = ..., perpetual_id: _Optional[int] = ..., total_size: _Optional[int] = ..., is_buy: bool = ..., fills: _Optional[_Iterable[_Union[MakerFill, _Mapping]]] = ...) -> None: ...

class MatchPerpetualDeleveraging(_message.Message):
    __slots__ = ("liquidated", "perpetual_id", "fills", "is_final_settlement")
    class Fill(_message.Message):
        __slots__ = ("offsetting_subaccount_id", "fill_amount")
        OFFSETTING_SUBACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
        FILL_AMOUNT_FIELD_NUMBER: _ClassVar[int]
        offsetting_subaccount_id: _subaccount_pb2.SubaccountId
        fill_amount: int
        def __init__(self, offsetting_subaccount_id: _Optional[_Union[_subaccount_pb2.SubaccountId, _Mapping]] = ..., fill_amount: _Optional[int] = ...) -> None: ...
    LIQUIDATED_FIELD_NUMBER: _ClassVar[int]
    PERPETUAL_ID_FIELD_NUMBER: _ClassVar[int]
    FILLS_FIELD_NUMBER: _ClassVar[int]
    IS_FINAL_SETTLEMENT_FIELD_NUMBER: _ClassVar[int]
    liquidated: _subaccount_pb2.SubaccountId
    perpetual_id: int
    fills: _containers.RepeatedCompositeFieldContainer[MatchPerpetualDeleveraging.Fill]
    is_final_settlement: bool
    def __init__(self, liquidated: _Optional[_Union[_subaccount_pb2.SubaccountId, _Mapping]] = ..., perpetual_id: _Optional[int] = ..., fills: _Optional[_Iterable[_Union[MatchPerpetualDeleveraging.Fill, _Mapping]]] = ..., is_final_settlement: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/bridge/query.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/bridge/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.dydxprotocol.bridge import bridge_event_info_pb2 as dydxprotocol_dot_bridge_dot_bridge__event__info__pb2
from v4_proto.dydxprotocol.bridge import params_pb2 as dydxprotocol_dot_bridge_dot_params__pb2
from v4_proto.dydxprotocol.bridge import tx_pb2 as dydxprotocol_dot_bridge_dot_tx__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x64ydxprotocol/bridge/query.proto\x12\x13\x64ydxprotocol.bridge\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a+dydxprotocol/bridge/bridge_event_info.proto\x1a dydxprotocol/bridge/params.proto\x1a\x1c\x64ydxprotocol/bridge/tx.proto\"\x19\n\x17QueryEventParamsRequest\"R\n\x18QueryEventParamsResponse\x12\x36\n\x06params\x18\x01 \x01(\x0b\x32 .dydxprotocol.bridge.EventParamsB\x04\xc8\xde\x1f\x00\"\x1b\n\x19QueryProposeParamsRequest\"V\n\x1aQueryProposeParamsResponse\x12\x38\n\x06params\x18\x01 \x01(\x0b\x32\".dydxprotocol.bridge.ProposeParamsB\x04\xc8\xde\x1f\x00\"\x1a\n\x18QuerySafetyParamsRequest\"T\n\x19QuerySafetyParamsResponse\x12\x37\n\x06params\x18\x01 \x01(\x0b\x32!.dydxprotocol.bridge.SafetyParamsB\x04\xc8\xde\x1f\x00\"#\n!QueryAcknowledgedEventInfoRequest\"^\n\"QueryAcknowledgedEventInfoResponse\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32$.dydxprotocol.bridge.BridgeEventInfoB\x04\xc8\xde\x1f\x00\"!\n\x1fQueryRecognizedEventInfoRequest\"\\\n QueryRecognizedEventInfoResponse\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32$.dydxprotocol.bridge.BridgeEventInfoB\x04\xc8\xde\x1f\x00\"<\n)QueryDelayedCompleteBridgeMessagesRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"w\n*QueryDelayedCompleteBridgeMessagesResponse\x12I\n\x08messages\x18\x01 \x03(\x0b\x32\x31.dydxprotocol.bridge.DelayedCompleteBridgeMessageB\x04\xc8\xde\x1f\x00\"s\n\x1c\x44\x65layedCompleteBridgeMessage\x12=\n\x07message\x18\x01 \x01(\x0b\x32&.dydxprotocol.bridge.MsgCompleteBridgeB\x04\xc8\xde\x1f\x00\x12\x14\n\x0c\x62lock_height\x18\x02 \x01(\r2\xc9\x08\n\x05Query\x12\x98\x01\n\x0b\x45ventParams\x12,.dydxprotocol.bridge.QueryEventParamsRequest\x1a-.dydxprotocol.bridge.QueryEventParamsResponse\",\x82\xd3\xe4\x93\x02&\x12$/dydxprotocol/v4/bridge/event_params\x12\xa0\x01\n\rProposeParams\x12..dydxprotocol.bridge.QueryProposeParamsRequest\x1a/.dydxprotocol.bridge.QueryProposeParamsResponse\".\x82\xd3\xe4\x93\x02(\x12&/dydxprotocol/v4/bridge/propose_params\x12\x9c\x01\n\x0cSafetyParams\x12-.dydxprotocol.bridge.QuerySafetyParamsRequest\x1a..dydxprotocol.bridge.QuerySafetyParamsResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/dydxprotocol/v4/bridge/safety_params\x12\xc1\x01\n\x15\x41\x63knowledgedEventInfo\x12\x36.dydxprotocol.bridge.QueryAcknowledgedEventInfoRequest\x1a\x37.dydxprotocol.bridge.QueryAcknowledgedEventInfoResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//dydxprotocol/v4/bridge/acknowledged_event_info\x12\xb9\x01\n\x13RecognizedEventInfo\x12\x34.dydxprotocol.bridge.QueryRecognizedEventInfoRequest\x1a\x35.dydxprotocol.bridge.QueryRecognizedEventInfoResponse\"5\x82\xd3\xe4\x93\x02/\x12-/dydxprotocol/v4/bridge/recognized_event_info\x12\xe2\x01\n\x1d\x44\x65layedCompleteBridgeMessages\x12>.dydxprotocol.bridge.QueryDelayedCompleteBridgeMessagesRequest\x1a?.dydxprotocol.bridge.QueryDelayedCompleteBridgeMessagesResponse\"@\x82\xd3\xe4\x93\x02:\x12\x38/dydxprotocol/v4/bridge/delayed_complete_bridge_messagesB:Z8github.com/dydxprotocol/v4-chain/protocol/x/bridge/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.bridge.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z8github.com/dydxprotocol/v4-chain/protocol/x/bridge/types'
  _globals['_QUERYEVENTPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYEVENTPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYPROPOSEPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPROPOSEPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYSAFETYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYSAFETYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYACKNOWLEDGEDEVENTINFORESPONSE'].fields_by_name['info']._loaded_options = None
  _globals['_QUERYACKNOWLEDGEDEVENTINFORESPONSE'].fields_by_name['info']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYRECOGNIZEDEVENTINFORESPONSE'].fields_by_name['info']._loaded_options = None
  _globals['_QUERYRECOGNIZEDEVENTINFORESPONSE'].fields_by_name['info']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYDELAYEDCOMPLETEBRIDGEMESSAGESRESPONSE'].fields_by_name['messages']._loaded_options = None
  _globals['_QUERYDELAYEDCOMPLETEBRIDGEMESSAGESRESPONSE'].fields_by_name['messages']._serialized_options = b'\310\336\037\000'
  _globals['_DELAYEDCOMPLETEBRIDGEMESSAGE'].fields_by_name['message']._loaded_options = None
  _globals['_DELAYEDCOMPLETEBRIDGEMESSAGE'].fields_by_name['message']._serialized_options = b'\310\336\037\000'
  _globals['_QUERY'].methods_by_name['EventParams']._loaded_options = None
  _globals['_QUERY'].methods_by_name['EventParams']._serialized_options = b'\202\323\344\223\002&\022$/dydxprotocol/v4/bridge/event_params'
  _globals['_QUERY'].methods_by_name['ProposeParams']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ProposeParams']._serialized_options = b'\202\323\344\223\002(\022&/dydxprotocol/v4/bridge/propose_params'
  _globals['_QUERY'].methods_by_name['SafetyParams']._loaded_options = None
  _globals['_QUERY'].methods_by_name['SafetyParams']._serialized_options = b'\202\323\344\223\002\'\022%/dydxprotocol/v4/bridge/safety_params'
  _globals['_QUERY'].methods_by_name['AcknowledgedEventInfo']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AcknowledgedEventInfo']._serialized_options = b'\202\323\344\223\0021\022//dydxprotocol/v4/bridge/acknowledged_event_info'
  _globals['_QUERY'].methods_by_name['RecognizedEventInfo']._loaded_options = None
  _globals['_QUERY'].methods_by_name['RecognizedEventInfo']._serialized_options = b'\202\323\344\223\002/\022-/dydxprotocol/v4/bridge/recognized_event_info'
  _globals['_QUERY'].methods_by_name['DelayedCompleteBridgeMessages']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DelayedCompleteBridgeMessages']._serialized_options = b'\202\323\344\223\002:\0228/dydxprotocol/v4/bridge/delayed_complete_bridge_messages'
  _globals['_QUERYEVENTPARAMSREQUEST']._serialized_start=217
  _globals['_QUERYEVENTPARAMSREQUEST']._serialized_end=242
  _globals['_QUERYEVENTPARAMSRESPONSE']._serialized_start=244
  _globals['_QUERYEVENTPARAMSRESPONSE']._serialized_end=326
  _globals['_QUERYPROPOSEPARAMSREQUEST']._serialized_start=328
  _globals['_QUERYPROPOSEPARAMSREQUEST']._serialized_end=355
  _globals['_QUERYPROPOSEPARAMSRESPONSE']._serialized_start=357
  _globals['_QUERYPROPOSEPARAMSRESPONSE']._serialized_end=443
  _globals['_QUERYSAFETYPARAMSREQUEST']._serialized_start=445
  _globals['_QUERYSAFETYPARAMSREQUEST']._serialized_end=471
  _globals['_QUERYSAFETYPARAMSRESPONSE']._serialized_start=473
  _globals['_QUERYSAFETYPARAMSRESPONSE']._serialized_end=557
  _globals['_QUERYACKNOWLEDGEDEVENTINFOREQUEST']._serialized_start=559
  _globals['_QUERYACKNOWLEDGEDEVENTINFOREQUEST']._serialized_end=594
  _globals['_QUERYACKNOWLEDGEDEVENTINFORESPONSE']._serialized_start=596
  _globals['_QUERYACKNOWLEDGEDEVENTINFORESPONSE']._serialized_end=690
  _globals['_QUERYRECOGNIZEDEVENTINFOREQUEST']._serialized_start=692
  _globals['_QUERYRECOGNIZEDEVENTINFOREQUEST']._serialized_end=725
  _globals['_QUERYRECOGNIZEDEVENTINFORESPONSE']._serialized_start=727
  _globals['_QUERYRECOGNIZEDEVENTINFORESPONSE']._serialized_end=819
  _globals['_QUERYDELAYEDCOMPLETEBRIDGEMESSAGESREQUEST']._serialized_start=821
  _globals['_QUERYDELAYEDCOMPLETEBRIDGEMESSAGESREQUEST']._serialized_end=881
  _globals['_QUERYDELAYEDCOMPLETEBRIDGEMESSAGESRESPONSE']._serialized_start=883
  _globals['_QUERYDELAYEDCOMPLETEBRIDGEMESSAGESRESPONSE']._serialized_end=1002
  _globals['_DELAYEDCOMPLETEBRIDGEMESSAGE']._serialized_start=1004
  _globals['_DELAYEDCOMPLETEBRIDGEMESSAGE']._serialized_end=1119
  _globals['_QUERY']._serialized_start=1122
  _globals['_QUERY']._serialized_end=2219
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class VaultStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    VAULT_STATUS_UNSPECIFIED: _ClassVar[VaultStatus]
    VAULT_STATUS_DEACTIVATED: _ClassVar[VaultStatus]
    VAULT_STATUS_STAND_BY: _ClassVar[VaultStatus]
    VAULT_STATUS_QUOTING: _ClassVar[VaultStatus]
    VAULT_STATUS_CLOSE_ONLY: _ClassVar[VaultStatus]
VAULT_STATUS_UNSPECIFIED: VaultStatus
VAULT_STATUS_DEACTIVATED: VaultStatus
VAULT_STATUS_STAND_BY: VaultStatus
VAULT_STATUS_QUOTING: VaultStatus
VAULT_STATUS_CLOSE_ONLY: VaultStatus



from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as _msg_pb2
from v4_proto.amino import amino_pb2 as _amino_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class MsgAddAuthenticator(_message.Message):
    __slots__ = ("sender", "authenticator_type", "data")
    SENDER_FIELD_NUMBER: _ClassVar[int]
    AUTHENTICATOR_TYPE_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    sender: str
    authenticator_type: str
    data: bytes
    def __init__(self, sender: _Optional[str] = ..., authenticator_type: _Optional[str] = ..., data: _Optional[bytes] = ...) -> None: ...

class MsgAddAuthenticatorResponse(_message.Message):
    __slots__ = ("success",)
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    def __init__(self, success: bool = ...) -> None: ...

class MsgRemoveAuthenticator(_message.Message):
    __slots__ = ("sender", "id")
    SENDER_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    sender: str
    id: int
    def __init__(self, sender: _Optional[str] = ..., id: _Optional[int] = ...) -> None: ...

class MsgRemoveAuthenticatorResponse(_message.Message):
    __slots__ = ("success",)
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    def __init__(self, success: bool = ...) -> None: ...

class MsgSetActiveState(_message.Message):
    __slots__ = ("authority", "active")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    authority: str
    active: bool
    def __init__(self, authority: _Optional[str] = ..., active: bool = ...) -> None: ...

class MsgSetActiveStateResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class TxExtension(_message.Message):
    __slots__ = ("selected_authenticators",)
    SELECTED_AUTHENTICATORS_FIELD_NUMBER: _ClassVar[int]
    selected_authenticators: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, selected_authenticators: _Optional[_Iterable[int]] = ...) -> None: ...



from v4_proto.amino import amino_pb2 as _amino_pb2
from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class BIP44Params(_message.Message):
    __slots__ = ("purpose", "coin_type", "account", "change", "address_index")
    PURPOSE_FIELD_NUMBER: _ClassVar[int]
    COIN_TYPE_FIELD_NUMBER: _ClassVar[int]
    ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    CHANGE_FIELD_NUMBER: _ClassVar[int]
    ADDRESS_INDEX_FIELD_NUMBER: _ClassVar[int]
    purpose: int
    coin_type: int
    account: int
    change: bool
    address_index: int
    def __init__(self, purpose: _Optional[int] = ..., coin_type: _Optional[int] = ..., account: _Optional[int] = ..., change: bool = ..., address_index: _Optional[int] = ...) -> None: ...



import datetime

from v4_proto.google.api import annotations_pb2 as _annotations_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ConfigRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ConfigResponse(_message.Message):
    __slots__ = ("minimum_gas_price", "pruning_keep_recent", "pruning_interval")
    MINIMUM_GAS_PRICE_FIELD_NUMBER: _ClassVar[int]
    PRUNING_KEEP_RECENT_FIELD_NUMBER: _ClassVar[int]
    PRUNING_INTERVAL_FIELD_NUMBER: _ClassVar[int]
    minimum_gas_price: str
    pruning_keep_recent: str
    pruning_interval: str
    def __init__(self, minimum_gas_price: _Optional[str] = ..., pruning_keep_recent: _Optional[str] = ..., pruning_interval: _Optional[str] = ...) -> None: ...

class StatusRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class StatusResponse(_message.Message):
    __slots__ = ("earliest_store_height", "height", "timestamp", "app_hash", "validator_hash")
    EARLIEST_STORE_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    APP_HASH_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_HASH_FIELD_NUMBER: _ClassVar[int]
    earliest_store_height: int
    height: int
    timestamp: _timestamp_pb2.Timestamp
    app_hash: bytes
    validator_hash: bytes
    def __init__(self, earliest_store_height: _Optional[int] = ..., height: _Optional[int] = ..., timestamp: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., app_hash: _Optional[bytes] = ..., validator_hash: _Optional[bytes] = ...) -> None: ...



from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from v4_proto.cosmos.circuit.v1 import types_pb2 as _types_pb2
from v4_proto.google.api import annotations_pb2 as _annotations_pb2
from v4_proto.cosmos.query.v1 import query_pb2 as _query_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryAccountRequest(_message.Message):
    __slots__ = ("address",)
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    address: str
    def __init__(self, address: _Optional[str] = ...) -> None: ...

class AccountResponse(_message.Message):
    __slots__ = ("permission",)
    PERMISSION_FIELD_NUMBER: _ClassVar[int]
    permission: _types_pb2.Permissions
    def __init__(self, permission: _Optional[_Union[_types_pb2.Permissions, _Mapping]] = ...) -> None: ...

class QueryAccountsRequest(_message.Message):
    __slots__ = ("pagination",)
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest
    def __init__(self, pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class AccountsResponse(_message.Message):
    __slots__ = ("accounts", "pagination")
    ACCOUNTS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    accounts: _containers.RepeatedCompositeFieldContainer[_types_pb2.GenesisAccountPermissions]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, accounts: _Optional[_Iterable[_Union[_types_pb2.GenesisAccountPermissions, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryDisabledListRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DisabledListResponse(_message.Message):
    __slots__ = ("disabled_list",)
    DISABLED_LIST_FIELD_NUMBER: _ClassVar[int]
    disabled_list: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, disabled_list: _Optional[_Iterable[str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/crypto/secp256r1/keys.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cosmos/crypto/secp256r1/keys.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"cosmos/crypto/secp256r1/keys.proto\x12\x17\x63osmos.crypto.secp256r1\x1a\x14gogoproto/gogo.proto\"\"\n\x06PubKey\x12\x18\n\x03key\x18\x01 \x01(\x0c\x42\x0b\xda\xde\x1f\x07\x65\x63\x64saPK\"&\n\x07PrivKey\x12\x1b\n\x06secret\x18\x01 \x01(\x0c\x42\x0b\xda\xde\x1f\x07\x65\x63\x64saSKB@Z2github.com/cosmos/cosmos-sdk/crypto/keys/secp256r1\xc8\xe1\x1e\x00\xd8\xe1\x1e\x00\xc8\xe3\x1e\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.crypto.secp256r1.keys_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z2github.com/cosmos/cosmos-sdk/crypto/keys/secp256r1\310\341\036\000\330\341\036\000\310\343\036\001'
  _globals['_PUBKEY'].fields_by_name['key']._loaded_options = None
  _globals['_PUBKEY'].fields_by_name['key']._serialized_options = b'\332\336\037\007ecdsaPK'
  _globals['_PRIVKEY'].fields_by_name['secret']._loaded_options = None
  _globals['_PRIVKEY'].fields_by_name['secret']._serialized_options = b'\332\336\037\007ecdsaSK'
  _globals['_PUBKEY']._serialized_start=85
  _globals['_PUBKEY']._serialized_end=119
  _globals['_PRIVKEY']._serialized_start=121
  _globals['_PRIVKEY']._serialized_end=159
# @@protoc_insertion_point(module_scope)



from v4_proto.cosmos.msg.v1 import msg_pb2 as _msg_pb2
from v4_proto.cosmos.circuit.v1 import types_pb2 as _types_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MsgAuthorizeCircuitBreaker(_message.Message):
    __slots__ = ("granter", "grantee", "permissions")
    GRANTER_FIELD_NUMBER: _ClassVar[int]
    GRANTEE_FIELD_NUMBER: _ClassVar[int]
    PERMISSIONS_FIELD_NUMBER: _ClassVar[int]
    granter: str
    grantee: str
    permissions: _types_pb2.Permissions
    def __init__(self, granter: _Optional[str] = ..., grantee: _Optional[str] = ..., permissions: _Optional[_Union[_types_pb2.Permissions, _Mapping]] = ...) -> None: ...

class MsgAuthorizeCircuitBreakerResponse(_message.Message):
    __slots__ = ("success",)
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    def __init__(self, success: bool = ...) -> None: ...

class MsgTripCircuitBreaker(_message.Message):
    __slots__ = ("authority", "msg_type_urls")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    MSG_TYPE_URLS_FIELD_NUMBER: _ClassVar[int]
    authority: str
    msg_type_urls: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, authority: _Optional[str] = ..., msg_type_urls: _Optional[_Iterable[str]] = ...) -> None: ...

class MsgTripCircuitBreakerResponse(_message.Message):
    __slots__ = ("success",)
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    def __init__(self, success: bool = ...) -> None: ...

class MsgResetCircuitBreaker(_message.Message):
    __slots__ = ("authority", "msg_type_urls")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    MSG_TYPE_URLS_FIELD_NUMBER: _ClassVar[int]
    authority: str
    msg_type_urls: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, authority: _Optional[str] = ..., msg_type_urls: _Optional[_Iterable[str]] = ...) -> None: ...

class MsgResetCircuitBreakerResponse(_message.Message):
    __slots__ = ("success",)
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    def __init__(self, success: bool = ...) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.dydxprotocol.prices import market_price_pb2 as _market_price_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class StreamPriceUpdate(_message.Message):
    __slots__ = ("market_id", "price", "snapshot")
    MARKET_ID_FIELD_NUMBER: _ClassVar[int]
    PRICE_FIELD_NUMBER: _ClassVar[int]
    SNAPSHOT_FIELD_NUMBER: _ClassVar[int]
    market_id: int
    price: _market_price_pb2.MarketPrice
    snapshot: bool
    def __init__(self, market_id: _Optional[int] = ..., price: _Optional[_Union[_market_price_pb2.MarketPrice, _Mapping]] = ..., snapshot: bool = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from v4_proto.cosmos.nft.v1beta1 import query_pb2 as cosmos_dot_nft_dot_v1beta1_dot_query__pb2

GRPC_GENERATED_VERSION = '1.75.1'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in cosmos/nft/v1beta1/query_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class QueryStub(object):
    """Query defines the gRPC querier service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Balance = channel.unary_unary(
                '/cosmos.nft.v1beta1.Query/Balance',
                request_serializer=cosmos_dot_nft_dot_v1beta1_dot_query__pb2.QueryBalanceRequest.SerializeToString,
                response_deserializer=cosmos_dot_nft_dot_v1beta1_dot_query__pb2.QueryBalanceResponse.FromString,
                _registered_method=True)
        self.Owner = channel.unary_unary(
                '/cosmos.nft.v1beta1.Query/Owner',
                request_serializer=cosmos_dot_nft_dot_v1beta1_dot_query__pb2.QueryOwnerRequest.SerializeToString,
                response_deserializer=cosmos_dot_nft_dot_v1beta1_dot_query__pb2.QueryOwnerResponse.FromString,
                _registered_method=True)
        self.Supply = channel.unary_unary(
                '/cosmos.nft.v1beta1.Query/Supply',
                request_serializer=cosmos_dot_nft_dot_v1beta1_dot_query__pb2.QuerySupplyRequest.SerializeToString,
                response_deserializer=cosmos_dot_nft_dot_v1beta1_dot_query__pb2.QuerySupplyResponse.FromString,
                _registered_method=True)
        self.NFTs = channel.unary_unary(
                '/cosmos.nft.v1beta1.Query/NFTs',
                request_serializer=cosmos_dot_nft_dot_v1beta1_dot_query__pb2.QueryNFTsRequest.SerializeToString,
                response_deserializer=cosmos_dot_nft_dot_v1beta1_dot_query__pb2.QueryNFTsResponse.FromString,
                _registered_method=True)
        self.NFT = channel.unary_unary(
                '/cosmos.nft.v1beta1.Query/NFT',
                request_serializer=cosmos_dot_nft_dot_v1beta1_dot_query__pb2.QueryNFTRequest.SerializeToString,
                response_deserializer=cosmos_dot_nft_dot_v1beta1_dot_query__pb2.QueryNFTResponse.FromString,
                _registered_method=True)
        self.Class = channel.unary_unary(
                '/cosmos.nft.v1beta1.Query/Class',
                request_serializer=cosmos_dot_nft_dot_v1beta1_dot_query__pb2.QueryClassRequest.SerializeToString,
                response_deserializer=cosmos_dot_nft_dot_v1beta1_dot_query__pb2.QueryClassResponse.FromString,
                _registered_method=True)
        self.Classes = channel.unary_unary(
                '/cosmos.nft.v1beta1.Query/Classes',
                request_serializer=cosmos_dot_nft_dot_v1beta1_dot_query__pb2.QueryClassesRequest.SerializeToString,
                response_deserializer=cosmos_dot_nft_dot_v1beta1_dot_query__pb2.QueryClassesResponse.FromString,
                _registered_method=True)


class QueryServicer(object):
    """Query defines the gRPC querier service.
    """

    def Balance(self, request, context):
        """Balance queries the number of NFTs of a given class owned by the owner, same as balanceOf in ERC721
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Owner(self, request, context):
        """Owner queries the owner of the NFT based on its class and id, same as ownerOf in ERC721
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Supply(self, request, context):
        """Supply queries the number of NFTs from the given class, same as totalSupply of ERC721.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def NFTs(self, request, context):
        """NFTs queries all NFTs of a given class or owner,choose at least one of the two, similar to tokenByIndex in
        ERC721Enumerable
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def NFT(self, request, context):
        """NFT queries an NFT based on its class and id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Class(self, request, context):
        """Class queries an NFT class based on its id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Classes(self, request, context):
        """Classes queries all NFT classes
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Balance': grpc.unary_unary_rpc_method_handler(
                    servicer.Balance,
                    request_deserializer=cosmos_dot_nft_dot_v1beta1_dot_query__pb2.QueryBalanceRequest.FromString,
                    response_serializer=cosmos_dot_nft_dot_v1beta1_dot_query__pb2.QueryBalanceResponse.SerializeToString,
            ),
            'Owner': grpc.unary_unary_rpc_method_handler(
                    servicer.Owner,
                    request_deserializer=cosmos_dot_nft_dot_v1beta1_dot_query__pb2.QueryOwnerRequest.FromString,
                    response_serializer=cosmos_dot_nft_dot_v1beta1_dot_query__pb2.QueryOwnerResponse.SerializeToString,
            ),
            'Supply': grpc.unary_unary_rpc_method_handler(
                    servicer.Supply,
                    request_deserializer=cosmos_dot_nft_dot_v1beta1_dot_query__pb2.QuerySupplyRequest.FromString,
                    response_serializer=cosmos_dot_nft_dot_v1beta1_dot_query__pb2.QuerySupplyResponse.SerializeToString,
            ),
            'NFTs': grpc.unary_unary_rpc_method_handler(
                    servicer.NFTs,
                    request_deserializer=cosmos_dot_nft_dot_v1beta1_dot_query__pb2.QueryNFTsRequest.FromString,
                    response_serializer=cosmos_dot_nft_dot_v1beta1_dot_query__pb2.QueryNFTsResponse.SerializeToString,
            ),
            'NFT': grpc.unary_unary_rpc_method_handler(
                    servicer.NFT,
                    request_deserializer=cosmos_dot_nft_dot_v1beta1_dot_query__pb2.QueryNFTRequest.FromString,
                    response_serializer=cosmos_dot_nft_dot_v1beta1_dot_query__pb2.QueryNFTResponse.SerializeToString,
            ),
            'Class': grpc.unary_unary_rpc_method_handler(
                    servicer.Class,
                    request_deserializer=cosmos_dot_nft_dot_v1beta1_dot_query__pb2.QueryClassRequest.FromString,
                    response_serializer=cosmos_dot_nft_dot_v1beta1_dot_query__pb2.QueryClassResponse.SerializeToString,
            ),
            'Classes': grpc.unary_unary_rpc_method_handler(
                    servicer.Classes,
                    request_deserializer=cosmos_dot_nft_dot_v1beta1_dot_query__pb2.QueryClassesRequest.FromString,
                    response_serializer=cosmos_dot_nft_dot_v1beta1_dot_query__pb2.QueryClassesResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'cosmos.nft.v1beta1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('cosmos.nft.v1beta1.Query', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the gRPC querier service.
    """

    @staticmethod
    def Balance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.nft.v1beta1.Query/Balance',
            cosmos_dot_nft_dot_v1beta1_dot_query__pb2.QueryBalanceRequest.SerializeToString,
            cosmos_dot_nft_dot_v1beta1_dot_query__pb2.QueryBalanceResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Owner(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.nft.v1beta1.Query/Owner',
            cosmos_dot_nft_dot_v1beta1_dot_query__pb2.QueryOwnerRequest.SerializeToString,
            cosmos_dot_nft_dot_v1beta1_dot_query__pb2.QueryOwnerResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Supply(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.nft.v1beta1.Query/Supply',
            cosmos_dot_nft_dot_v1beta1_dot_query__pb2.QuerySupplyRequest.SerializeToString,
            cosmos_dot_nft_dot_v1beta1_dot_query__pb2.QuerySupplyResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def NFTs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.nft.v1beta1.Query/NFTs',
            cosmos_dot_nft_dot_v1beta1_dot_query__pb2.QueryNFTsRequest.SerializeToString,
            cosmos_dot_nft_dot_v1beta1_dot_query__pb2.QueryNFTsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def NFT(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.nft.v1beta1.Query/NFT',
            cosmos_dot_nft_dot_v1beta1_dot_query__pb2.QueryNFTRequest.SerializeToString,
            cosmos_dot_nft_dot_v1beta1_dot_query__pb2.QueryNFTResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Class(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.nft.v1beta1.Query/Class',
            cosmos_dot_nft_dot_v1beta1_dot_query__pb2.QueryClassRequest.SerializeToString,
            cosmos_dot_nft_dot_v1beta1_dot_query__pb2.QueryClassResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Classes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.nft.v1beta1.Query/Classes',
            cosmos_dot_nft_dot_v1beta1_dot_query__pb2.QueryClassesRequest.SerializeToString,
            cosmos_dot_nft_dot_v1beta1_dot_query__pb2.QueryClassesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class AccountAuthenticator(_message.Message):
    __slots__ = ("id", "type", "config")
    ID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    CONFIG_FIELD_NUMBER: _ClassVar[int]
    id: int
    type: str
    config: bytes
    def __init__(self, id: _Optional[int] = ..., type: _Optional[str] = ..., config: _Optional[bytes] = ...) -> None: ...



from google.protobuf import any_pb2 as _any_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ("evidence",)
    EVIDENCE_FIELD_NUMBER: _ClassVar[int]
    evidence: _containers.RepeatedCompositeFieldContainer[_any_pb2.Any]
    def __init__(self, evidence: _Optional[_Iterable[_Union[_any_pb2.Any, _Mapping]]] = ...) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.dydxprotocol.bridge import bridge_event_pb2 as _bridge_event_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AddBridgeEventsRequest(_message.Message):
    __slots__ = ("bridge_events",)
    BRIDGE_EVENTS_FIELD_NUMBER: _ClassVar[int]
    bridge_events: _containers.RepeatedCompositeFieldContainer[_bridge_event_pb2.BridgeEvent]
    def __init__(self, bridge_events: _Optional[_Iterable[_Union[_bridge_event_pb2.BridgeEvent, _Mapping]]] = ...) -> None: ...

class AddBridgeEventsResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/vault/vault.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/vault/vault.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x64ydxprotocol/vault/vault.proto\x12\x12\x64ydxprotocol.vault\"F\n\x07VaultId\x12+\n\x04type\x18\x01 \x01(\x0e\x32\x1d.dydxprotocol.vault.VaultType\x12\x0e\n\x06number\x18\x02 \x01(\r*<\n\tVaultType\x12\x1a\n\x16VAULT_TYPE_UNSPECIFIED\x10\x00\x12\x13\n\x0fVAULT_TYPE_CLOB\x10\x01*\x9b\x01\n\x0bVaultStatus\x12\x1c\n\x18VAULT_STATUS_UNSPECIFIED\x10\x00\x12\x1c\n\x18VAULT_STATUS_DEACTIVATED\x10\x01\x12\x19\n\x15VAULT_STATUS_STAND_BY\x10\x02\x12\x18\n\x14VAULT_STATUS_QUOTING\x10\x03\x12\x1b\n\x17VAULT_STATUS_CLOSE_ONLY\x10\x04\x42\x39Z7github.com/dydxprotocol/v4-chain/protocol/x/vault/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.vault.vault_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/dydxprotocol/v4-chain/protocol/x/vault/types'
  _globals['_VAULTTYPE']._serialized_start=126
  _globals['_VAULTTYPE']._serialized_end=186
  _globals['_VAULTSTATUS']._serialized_start=189
  _globals['_VAULTSTATUS']._serialized_end=344
  _globals['_VAULTID']._serialized_start=54
  _globals['_VAULTID']._serialized_end=124
# @@protoc_insertion_point(module_scope)



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Snapshot(_message.Message):
    __slots__ = ("height", "format", "chunks", "hash", "metadata")
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    CHUNKS_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    height: int
    format: int
    chunks: int
    hash: bytes
    metadata: Metadata
    def __init__(self, height: _Optional[int] = ..., format: _Optional[int] = ..., chunks: _Optional[int] = ..., hash: _Optional[bytes] = ..., metadata: _Optional[_Union[Metadata, _Mapping]] = ...) -> None: ...

class Metadata(_message.Message):
    __slots__ = ("chunk_hashes",)
    CHUNK_HASHES_FIELD_NUMBER: _ClassVar[int]
    chunk_hashes: _containers.RepeatedScalarFieldContainer[bytes]
    def __init__(self, chunk_hashes: _Optional[_Iterable[bytes]] = ...) -> None: ...

class SnapshotItem(_message.Message):
    __slots__ = ("store", "iavl", "extension", "extension_payload")
    STORE_FIELD_NUMBER: _ClassVar[int]
    IAVL_FIELD_NUMBER: _ClassVar[int]
    EXTENSION_FIELD_NUMBER: _ClassVar[int]
    EXTENSION_PAYLOAD_FIELD_NUMBER: _ClassVar[int]
    store: SnapshotStoreItem
    iavl: SnapshotIAVLItem
    extension: SnapshotExtensionMeta
    extension_payload: SnapshotExtensionPayload
    def __init__(self, store: _Optional[_Union[SnapshotStoreItem, _Mapping]] = ..., iavl: _Optional[_Union[SnapshotIAVLItem, _Mapping]] = ..., extension: _Optional[_Union[SnapshotExtensionMeta, _Mapping]] = ..., extension_payload: _Optional[_Union[SnapshotExtensionPayload, _Mapping]] = ...) -> None: ...

class SnapshotStoreItem(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class SnapshotIAVLItem(_message.Message):
    __slots__ = ("key", "value", "version", "height")
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    key: bytes
    value: bytes
    version: int
    height: int
    def __init__(self, key: _Optional[bytes] = ..., value: _Optional[bytes] = ..., version: _Optional[int] = ..., height: _Optional[int] = ...) -> None: ...

class SnapshotExtensionMeta(_message.Message):
    __slots__ = ("name", "format")
    NAME_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    name: str
    format: int
    def __init__(self, name: _Optional[str] = ..., format: _Optional[int] = ...) -> None: ...

class SnapshotExtensionPayload(_message.Message):
    __slots__ = ("payload",)
    PAYLOAD_FIELD_NUMBER: _ClassVar[int]
    payload: bytes
    def __init__(self, payload: _Optional[bytes] = ...) -> None: ...



import datetime

from v4_proto.cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import any_pb2 as _any_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.amino import amino_pb2 as _amino_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class VoteOption(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    VOTE_OPTION_UNSPECIFIED: _ClassVar[VoteOption]
    VOTE_OPTION_YES: _ClassVar[VoteOption]
    VOTE_OPTION_ABSTAIN: _ClassVar[VoteOption]
    VOTE_OPTION_NO: _ClassVar[VoteOption]
    VOTE_OPTION_NO_WITH_VETO: _ClassVar[VoteOption]

class ProposalStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    PROPOSAL_STATUS_UNSPECIFIED: _ClassVar[ProposalStatus]
    PROPOSAL_STATUS_DEPOSIT_PERIOD: _ClassVar[ProposalStatus]
    PROPOSAL_STATUS_VOTING_PERIOD: _ClassVar[ProposalStatus]
    PROPOSAL_STATUS_PASSED: _ClassVar[ProposalStatus]
    PROPOSAL_STATUS_REJECTED: _ClassVar[ProposalStatus]
    PROPOSAL_STATUS_FAILED: _ClassVar[ProposalStatus]
VOTE_OPTION_UNSPECIFIED: VoteOption
VOTE_OPTION_YES: VoteOption
VOTE_OPTION_ABSTAIN: VoteOption
VOTE_OPTION_NO: VoteOption
VOTE_OPTION_NO_WITH_VETO: VoteOption
PROPOSAL_STATUS_UNSPECIFIED: ProposalStatus
PROPOSAL_STATUS_DEPOSIT_PERIOD: ProposalStatus
PROPOSAL_STATUS_VOTING_PERIOD: ProposalStatus
PROPOSAL_STATUS_PASSED: ProposalStatus
PROPOSAL_STATUS_REJECTED: ProposalStatus
PROPOSAL_STATUS_FAILED: ProposalStatus

class WeightedVoteOption(_message.Message):
    __slots__ = ("option", "weight")
    OPTION_FIELD_NUMBER: _ClassVar[int]
    WEIGHT_FIELD_NUMBER: _ClassVar[int]
    option: VoteOption
    weight: str
    def __init__(self, option: _Optional[_Union[VoteOption, str]] = ..., weight: _Optional[str] = ...) -> None: ...

class TextProposal(_message.Message):
    __slots__ = ("title", "description")
    TITLE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    title: str
    description: str
    def __init__(self, title: _Optional[str] = ..., description: _Optional[str] = ...) -> None: ...

class Deposit(_message.Message):
    __slots__ = ("proposal_id", "depositor", "amount")
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    DEPOSITOR_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    proposal_id: int
    depositor: str
    amount: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    def __init__(self, proposal_id: _Optional[int] = ..., depositor: _Optional[str] = ..., amount: _Optional[_Iterable[_Union[_coin_pb2.Coin, _Mapping]]] = ...) -> None: ...

class Proposal(_message.Message):
    __slots__ = ("proposal_id", "content", "status", "final_tally_result", "submit_time", "deposit_end_time", "total_deposit", "voting_start_time", "voting_end_time")
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    FINAL_TALLY_RESULT_FIELD_NUMBER: _ClassVar[int]
    SUBMIT_TIME_FIELD_NUMBER: _ClassVar[int]
    DEPOSIT_END_TIME_FIELD_NUMBER: _ClassVar[int]
    TOTAL_DEPOSIT_FIELD_NUMBER: _ClassVar[int]
    VOTING_START_TIME_FIELD_NUMBER: _ClassVar[int]
    VOTING_END_TIME_FIELD_NUMBER: _ClassVar[int]
    proposal_id: int
    content: _any_pb2.Any
    status: ProposalStatus
    final_tally_result: TallyResult
    submit_time: _timestamp_pb2.Timestamp
    deposit_end_time: _timestamp_pb2.Timestamp
    total_deposit: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    voting_start_time: _timestamp_pb2.Timestamp
    voting_end_time: _timestamp_pb2.Timestamp
    def __init__(self, proposal_id: _Optional[int] = ..., content: _Optional[_Union[_any_pb2.Any, _Mapping]] = ..., status: _Optional[_Union[ProposalStatus, str]] = ..., final_tally_result: _Optional[_Union[TallyResult, _Mapping]] = ..., submit_time: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., deposit_end_time: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., total_deposit: _Optional[_Iterable[_Union[_coin_pb2.Coin, _Mapping]]] = ..., voting_start_time: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., voting_end_time: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class TallyResult(_message.Message):
    __slots__ = ("yes", "abstain", "no", "no_with_veto")
    YES_FIELD_NUMBER: _ClassVar[int]
    ABSTAIN_FIELD_NUMBER: _ClassVar[int]
    NO_FIELD_NUMBER: _ClassVar[int]
    NO_WITH_VETO_FIELD_NUMBER: _ClassVar[int]
    yes: str
    abstain: str
    no: str
    no_with_veto: str
    def __init__(self, yes: _Optional[str] = ..., abstain: _Optional[str] = ..., no: _Optional[str] = ..., no_with_veto: _Optional[str] = ...) -> None: ...

class Vote(_message.Message):
    __slots__ = ("proposal_id", "voter", "option", "options")
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    VOTER_FIELD_NUMBER: _ClassVar[int]
    OPTION_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    proposal_id: int
    voter: str
    option: VoteOption
    options: _containers.RepeatedCompositeFieldContainer[WeightedVoteOption]
    def __init__(self, proposal_id: _Optional[int] = ..., voter: _Optional[str] = ..., option: _Optional[_Union[VoteOption, str]] = ..., options: _Optional[_Iterable[_Union[WeightedVoteOption, _Mapping]]] = ...) -> None: ...

class DepositParams(_message.Message):
    __slots__ = ("min_deposit", "max_deposit_period")
    MIN_DEPOSIT_FIELD_NUMBER: _ClassVar[int]
    MAX_DEPOSIT_PERIOD_FIELD_NUMBER: _ClassVar[int]
    min_deposit: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    max_deposit_period: _duration_pb2.Duration
    def __init__(self, min_deposit: _Optional[_Iterable[_Union[_coin_pb2.Coin, _Mapping]]] = ..., max_deposit_period: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ...) -> None: ...

class VotingParams(_message.Message):
    __slots__ = ("voting_period",)
    VOTING_PERIOD_FIELD_NUMBER: _ClassVar[int]
    voting_period: _duration_pb2.Duration
    def __init__(self, voting_period: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ...) -> None: ...

class TallyParams(_message.Message):
    __slots__ = ("quorum", "threshold", "veto_threshold")
    QUORUM_FIELD_NUMBER: _ClassVar[int]
    THRESHOLD_FIELD_NUMBER: _ClassVar[int]
    VETO_THRESHOLD_FIELD_NUMBER: _ClassVar[int]
    quorum: bytes
    threshold: bytes
    veto_threshold: bytes
    def __init__(self, quorum: _Optional[bytes] = ..., threshold: _Optional[bytes] = ..., veto_threshold: _Optional[bytes] = ...) -> None: ...



from v4_proto.cosmos.app.v1alpha1 import module_pb2 as _module_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Module(_message.Message):
    __slots__ = ("app_name", "begin_blockers", "end_blockers", "init_genesis", "export_genesis", "override_store_keys", "order_migrations", "precommiters", "prepare_check_staters")
    APP_NAME_FIELD_NUMBER: _ClassVar[int]
    BEGIN_BLOCKERS_FIELD_NUMBER: _ClassVar[int]
    END_BLOCKERS_FIELD_NUMBER: _ClassVar[int]
    INIT_GENESIS_FIELD_NUMBER: _ClassVar[int]
    EXPORT_GENESIS_FIELD_NUMBER: _ClassVar[int]
    OVERRIDE_STORE_KEYS_FIELD_NUMBER: _ClassVar[int]
    ORDER_MIGRATIONS_FIELD_NUMBER: _ClassVar[int]
    PRECOMMITERS_FIELD_NUMBER: _ClassVar[int]
    PREPARE_CHECK_STATERS_FIELD_NUMBER: _ClassVar[int]
    app_name: str
    begin_blockers: _containers.RepeatedScalarFieldContainer[str]
    end_blockers: _containers.RepeatedScalarFieldContainer[str]
    init_genesis: _containers.RepeatedScalarFieldContainer[str]
    export_genesis: _containers.RepeatedScalarFieldContainer[str]
    override_store_keys: _containers.RepeatedCompositeFieldContainer[StoreKeyConfig]
    order_migrations: _containers.RepeatedScalarFieldContainer[str]
    precommiters: _containers.RepeatedScalarFieldContainer[str]
    prepare_check_staters: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, app_name: _Optional[str] = ..., begin_blockers: _Optional[_Iterable[str]] = ..., end_blockers: _Optional[_Iterable[str]] = ..., init_genesis: _Optional[_Iterable[str]] = ..., export_genesis: _Optional[_Iterable[str]] = ..., override_store_keys: _Optional[_Iterable[_Union[StoreKeyConfig, _Mapping]]] = ..., order_migrations: _Optional[_Iterable[str]] = ..., precommiters: _Optional[_Iterable[str]] = ..., prepare_check_staters: _Optional[_Iterable[str]] = ...) -> None: ...

class StoreKeyConfig(_message.Message):
    __slots__ = ("module_name", "kv_store_key")
    MODULE_NAME_FIELD_NUMBER: _ClassVar[int]
    KV_STORE_KEY_FIELD_NUMBER: _ClassVar[int]
    module_name: str
    kv_store_key: str
    def __init__(self, module_name: _Optional[str] = ..., kv_store_key: _Optional[str] = ...) -> None: ...



from google.protobuf import any_pb2 as _any_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Config(_message.Message):
    __slots__ = ("modules", "golang_bindings")
    MODULES_FIELD_NUMBER: _ClassVar[int]
    GOLANG_BINDINGS_FIELD_NUMBER: _ClassVar[int]
    modules: _containers.RepeatedCompositeFieldContainer[ModuleConfig]
    golang_bindings: _containers.RepeatedCompositeFieldContainer[GolangBinding]
    def __init__(self, modules: _Optional[_Iterable[_Union[ModuleConfig, _Mapping]]] = ..., golang_bindings: _Optional[_Iterable[_Union[GolangBinding, _Mapping]]] = ...) -> None: ...

class ModuleConfig(_message.Message):
    __slots__ = ("name", "config", "golang_bindings")
    NAME_FIELD_NUMBER: _ClassVar[int]
    CONFIG_FIELD_NUMBER: _ClassVar[int]
    GOLANG_BINDINGS_FIELD_NUMBER: _ClassVar[int]
    name: str
    config: _any_pb2.Any
    golang_bindings: _containers.RepeatedCompositeFieldContainer[GolangBinding]
    def __init__(self, name: _Optional[str] = ..., config: _Optional[_Union[_any_pb2.Any, _Mapping]] = ..., golang_bindings: _Optional[_Iterable[_Union[GolangBinding, _Mapping]]] = ...) -> None: ...

class GolangBinding(_message.Message):
    __slots__ = ("interface_type", "implementation")
    INTERFACE_TYPE_FIELD_NUMBER: _ClassVar[int]
    IMPLEMENTATION_FIELD_NUMBER: _ClassVar[int]
    interface_type: str
    implementation: str
    def __init__(self, interface_type: _Optional[str] = ..., implementation: _Optional[str] = ...) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.dydxprotocol.subaccounts import subaccount_pb2 as _subaccount_pb2
from v4_proto.dydxprotocol.clob import liquidations_pb2 as _liquidations_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class LiquidateSubaccountsRequest(_message.Message):
    __slots__ = ("block_height", "liquidatable_subaccount_ids", "negative_tnc_subaccount_ids", "subaccount_open_position_info")
    BLOCK_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    LIQUIDATABLE_SUBACCOUNT_IDS_FIELD_NUMBER: _ClassVar[int]
    NEGATIVE_TNC_SUBACCOUNT_IDS_FIELD_NUMBER: _ClassVar[int]
    SUBACCOUNT_OPEN_POSITION_INFO_FIELD_NUMBER: _ClassVar[int]
    block_height: int
    liquidatable_subaccount_ids: _containers.RepeatedCompositeFieldContainer[_subaccount_pb2.SubaccountId]
    negative_tnc_subaccount_ids: _containers.RepeatedCompositeFieldContainer[_subaccount_pb2.SubaccountId]
    subaccount_open_position_info: _containers.RepeatedCompositeFieldContainer[_liquidations_pb2.SubaccountOpenPositionInfo]
    def __init__(self, block_height: _Optional[int] = ..., liquidatable_subaccount_ids: _Optional[_Iterable[_Union[_subaccount_pb2.SubaccountId, _Mapping]]] = ..., negative_tnc_subaccount_ids: _Optional[_Iterable[_Union[_subaccount_pb2.SubaccountId, _Mapping]]] = ..., subaccount_open_position_info: _Optional[_Iterable[_Union[_liquidations_pb2.SubaccountOpenPositionInfo, _Mapping]]] = ...) -> None: ...

class LiquidateSubaccountsResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.google.api import annotations_pb2 as _annotations_pb2
from v4_proto.dydxprotocol.rewards import params_pb2 as _params_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryParamsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryParamsResponse(_message.Message):
    __slots__ = ("params",)
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    params: _params_pb2.Params
    def __init__(self, params: _Optional[_Union[_params_pb2.Params, _Mapping]] = ...) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.cosmos.slashing.v1beta1 import slashing_pb2 as _slashing_pb2
from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.amino import amino_pb2 as _amino_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ("params", "signing_infos", "missed_blocks")
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    SIGNING_INFOS_FIELD_NUMBER: _ClassVar[int]
    MISSED_BLOCKS_FIELD_NUMBER: _ClassVar[int]
    params: _slashing_pb2.Params
    signing_infos: _containers.RepeatedCompositeFieldContainer[SigningInfo]
    missed_blocks: _containers.RepeatedCompositeFieldContainer[ValidatorMissedBlocks]
    def __init__(self, params: _Optional[_Union[_slashing_pb2.Params, _Mapping]] = ..., signing_infos: _Optional[_Iterable[_Union[SigningInfo, _Mapping]]] = ..., missed_blocks: _Optional[_Iterable[_Union[ValidatorMissedBlocks, _Mapping]]] = ...) -> None: ...

class SigningInfo(_message.Message):
    __slots__ = ("address", "validator_signing_info")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_SIGNING_INFO_FIELD_NUMBER: _ClassVar[int]
    address: str
    validator_signing_info: _slashing_pb2.ValidatorSigningInfo
    def __init__(self, address: _Optional[str] = ..., validator_signing_info: _Optional[_Union[_slashing_pb2.ValidatorSigningInfo, _Mapping]] = ...) -> None: ...

class ValidatorMissedBlocks(_message.Message):
    __slots__ = ("address", "missed_blocks")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    MISSED_BLOCKS_FIELD_NUMBER: _ClassVar[int]
    address: str
    missed_blocks: _containers.RepeatedCompositeFieldContainer[MissedBlock]
    def __init__(self, address: _Optional[str] = ..., missed_blocks: _Optional[_Iterable[_Union[MissedBlock, _Mapping]]] = ...) -> None: ...

class MissedBlock(_message.Message):
    __slots__ = ("index", "missed")
    INDEX_FIELD_NUMBER: _ClassVar[int]
    MISSED_FIELD_NUMBER: _ClassVar[int]
    index: int
    missed: bool
    def __init__(self, index: _Optional[int] = ..., missed: bool = ...) -> None: ...
